@@ -1,6 +1,8 @@
 from .controllers.downloader import DownloaderController
 from sentry_sdk.integrations.sanic import SanicIntegration
 from .controllers.scheduler import SchedulerController
+from .controllers.version import VersionController
+from .controllers.auth import AuthController
 from .controllers.manager import ManagerController
 from .controllers.assets import AssetsController
 from .controllers.secret import SecretController
@@ -8,6 +10,7 @@ from .controllers.notebooks import NbController
 from .controllers.timezone import TimezoneController
 from .controllers.jobs import JobsController
 from .controllers.logs import LogsController
+from .controllers.credits import CreditsController
 from sanic_openapi import swagger_blueprint
 from .controllers.env import EnvController
 from .controllers.performance import PerformanceController
@@ -38,13 +41,16 @@ from naas.ntypes import (
     t_secret,
     t_tz,
     t_downloader,
+    t_credits,
+    t_auth,
+    t_version,
 )
 
 # TODO remove this fix when papermill and nest_asyncio support uvloop
 asyncio.set_event_loop_policy(None)
 nest_asyncio.apply()
 
-__version__ = "1.22.7"
+__version__ = "2.1.9"
 
 
 class Runner:
@@ -89,6 +95,26 @@ class Runner:
                 DownloaderController.as_view(self.__logger),
                 f"/{t_downloader}",
             )
+            self.__app.add_route(
+                CreditsController.TransactionController.as_view(self.__logger),
+                f"/{t_credits}/transactions",
+            )
+            self.__app.add_route(
+                CreditsController.BalanceController.as_view(self.__logger),
+                f"/{t_credits}/balance",
+            )
+            self.__app.add_route(
+                CreditsController.PlanController.as_view(self.__logger),
+                f"/{t_credits}/plan",
+            )
+            self.__app.add_route(
+                AuthController.UserController.as_view(self.__logger),
+                f"/{t_auth}/user/me",
+            )
+            self.__app.add_route(
+                VersionController.UpdateController.as_view(self.__logger),
+                f"/{t_version}/update",
+            )
             self.__app.add_route(
                 AssetsController.as_view(
                     self.__logger, self.__jobs, self.__path_lib_files
